OpenDialogEntity class

Inheritance

Constructors

OpenDialogEntity(String? appID, {DisplayConditionsEntity? conditions, String? dialogID})
const

Properties

actionType → String?
finalinherited
appID → String?
finalinherited
conditions → DisplayConditionsEntity?
finalinherited
dialogID → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? appId, DisplayConditionsEntity? conditions, String? dialogID}) → ActionEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map snap) → ActionEntity
override

Constants

label → const String