SwitchAppEntity class

Inheritance

Constructors

SwitchAppEntity(String? appID, {DisplayConditionsEntity? conditions, String? toAppID})
const

Properties

actionType → String?
finalinherited
appID → String?
finalinherited
conditions → DisplayConditionsEntity?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toAppID → String?
final

Methods

copyWith({String? appId, DisplayConditionsEntity? conditions, String? toAppID}) → ActionEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map snap) → ActionEntity
override

Constants

label → const String